tlslite.utils.rc4.RC4

Package tlslite :: Package utils :: Module rc4 :: Class RC4 |
[hide private]
[frames] | no frames]

# Class RC4

source code

Known Subclasses:
  - openssl_rc4.OpenSSL_RC4
  - , pycrypto_rc4.PyCrypto_RC4
  - , python_rc4.Python_RC4

Instance Methods | [hide private]
__init__(self, keyBytes, implementation) | source code
decrypt(self, ciphertext) | source code
encrypt(self, plaintext) | source code